from django.shortcuts import render, redirect
from rest_framework.views import APIView
from rest_framework.response import Response
import random
import json,time
import jwt
import redis
from utils.pay import AlipayTool
from utils.sms_code import send_message
from myapp.models import OrderModel
# Create your views here.
from django.conf import settings
class Sms_CodeView(APIView):
    def get(self, request):
        """生成短信验证码"""
        mobile = request.query_params.get('mobile')
        resp = send_message(mobile)
        print(resp)
        return Response({
            "code":200,
            "msg":"发送短信验证码成功"
        })

from  myapp.models import UserModel
from utils import myjwt

class LoginView(APIView):
    def post(self,request):
        mobile=request.data.get("mobile")
        code=request.data.get("code")

        print(mobile,"前端手机号")

        cls = redis.Redis()
        redis_data = cls.get("sms_%s"%mobile)
        print("数据库验证码",redis_data)


        if not redis_data  or redis_data.decode() !=code:
            return Response({
                "code":300,
                "msg":"验证码过期，或者不对"
            })
        user_info = UserModel.objects.filter(mobile=mobile).first()
        print('xxxxxxxxxxxxx',user_info)
        if not user_info:
            username1="用户"+mobile[-4:]

            UserModel.objects.create(username=username1,mobile=mobile,img="")

            user_info=UserModel.objects.get(username=username1,mobile=mobile)
            payload={
                    "id":user_info.id,
                    "name":user_info.username,
                    "mobile":user_info.mobile,
                }
            token=jwt.encode(payload=payload,key=settings.SECRET_KEY,algorithm='HS256')
            return Response({
                "code": 200,
                "msg": "登录成功",
                "data": token,
            })
        user_info = UserModel.objects.filter(mobile=mobile).first()
        payload = {
            "id": user_info.id,
            "name": user_info.username,
            "mobile": user_info.mobile,
        }
        token = jwt.encode(payload=payload, key=settings.SECRET_KEY, algorithm='HS256')
        return Response({
            "code":200,
            "msg":"登录成功",
            "data":token,
        })

class LogoutView(APIView):
    def post(self,request):
        return Response({
            "code":200,
            "msg":"退出登录成功，请重新登录"
        })

from  utils.LoginTools import check_login
from myapp.models import AddressModel

class  ShowUser_address(APIView):
    @check_login
    def get(self,request):
        user=request.user
        user_addres=user.addressmodel_set()
        temp=[]
        for i in user_addres:
            temp_dict={
                "uid":i.id,
                "name":i.name,
                "phone":i.phone,
                "address":i.address,
                "is_mo":i.is_mo,
            }
            temp.append(temp_dict)
        return Response({
            "code":200,
            "msg":"获取登录用户收货地址成功",
            "data":temp,
        })

    @check_login
    def post(self,request):
        user_id = request.id
        name= request.data.get("name")
        phone= request.data.get("phone")
        address=request.data.get("address")
        is_mo=request.data.get("is_mo")

        try:
            AddressModel.objects.create(uid=user_id,name=name,phone=phone,address=address,is_mo=is_mo)
        except Exception as e:
            print(e,"用户添加收货地址报错")
        return Response({
            "code": 200,
            "msg": "添加登录用户收货地址成功",
        })
    @check_login
    def put(self,request):
        user_id=request.user

        id=request.data.get("id")
        name= request.data.get("name")
        phone= request.data.get("phone")
        address=request.data.get("address")
        is_mo=request.data.get("is_mo")

        try:
            AddressModel.objects.filter(id=id).update(name=name,phone=phone,address=address,is_mo=is_mo)
        except Exception as e:
            print(e,"用户修改收货地址报错")
        return Response({
                "code":200,
                "msg":"修改用户收货地址成功",
            })


from myapp.models import CouponModel
class  Showuser_Coupon(APIView):
    @check_login
    def get(self,request):
        id=request.id
        user_coup=CouponModel.objects.filter(uid=id).first()
        temp=[]

        for i in user_coup:
            temp_dict={
                "id":i.uid,
                "name":i.name,
                "price":i.price,
                "type":i.type,
                "start_time":i.start_time,
                "end_time": i.end_time,
                "time": i.time,
            }
            temp.append(temp_dict)
        return Response({
            "code":200,
            "msg":"获取用户优惠卷成功",
            "data":temp,
        })


from utils.qiniu_token import qiniu_token

class QNYtoken(APIView):
    def get(self,request):
        token=qiniu_token()
        return Response({
            "code":200,
            "token":token
        })

class Show_userInfo(APIView):
    @check_login
    def get(self,request):
        users_id = request.id
        users = UserModel.objects.filter(id=request.id)
        temp=[]
        for i in users:
            temp_dict={
                "id":i.id,
                "username":i.username,
                "mobile":i.mobile,
                "img" :i.img,
                "login_time":i.login_time,
                "intro":i.intro,
                "status":i.status,
                "time":time.strftime('%Y-%m-%d',time.localtime(int(i.vip_end_time)))
            }
            temp.append(temp_dict)
        return Response({
            "code":200,
            "msg":"获取登录用户信息成功",
            "data":temp,
        })
    @check_login
    def put(self,request):
        username=request.data.get("username")
        img=request.data.get("img")
        id=request.id

        try:
            UserModel.objects.filter(id=id).update(username=username,img=img)
        except Exception as e:
            print(e)
        return Response({
            "code":200,
            "msg":"修改登录用户信息成功"
        })

from myapp.models import VipListModel
class VipListView(APIView):
    def get(self,request):
        vip_list = VipListModel.objects.all()

        vip_all = []
        for item in vip_list:
            vip_all.append({
                "id": item.id,
                "name": item.name,
                "price": item.price,
                "time_text": item.time_text,
                "time": item.time,
                "day_price": "%.2f" % (int(item.price) / (int(item.time) / 86400))
            })

        return Response({
            "code":200,
            "msg":"获取所有vip类型成功",
            "data":vip_all
        })


from datetime import datetime
from myapp.models import CategoryModel,FoodModel,BussessModel,PayOrderModel


class CateView(APIView):
    def get(self,request):
        data = CategoryModel.objects.all().order_by('-num')
        lst = []
        for i in data:
            lst.append({
                "id":i.id,
                'name':i.name,
                "num":i.num
            })
        return Response({
            "code":200,
            'msg':'获取成功',
            'data':lst
        })



class Add_OrderView(APIView):
    @check_login
    def get(self,request):
        user_id = request.id
        orders=PayOrderModel.objects.filter(uid=user_id).all()

        temp=[]
        all_price=[]
        for i in orders:

            all_price+=i.fid.price
            order_temp={
                "id":i.id,
                "order_num":i.order_num,
                "uid": i.uid,
                "bid=": i.bid,
                "fid": i.fid,
                "amount": i.amount,
                "status":i.status,
            }
            temp.append(order_temp)
        return Response({
            "code":200,
            "msg":"获取用户所有订单成功",
            "all_price": all_price,
        })

    @check_login
    def post(self,request):
        user_id = request.id
        bid = request.data.get("bid")
        fid = request.data.get("fid")

        # 生成订单号
        order_num = "T" + datetime.strftime(datetime.now(), "%Y%m%d%H%M%S") + str(
            random.randint(100000, 999999)) + str(
            random.randint(100000, 999999))

        price=FoodModel.objects.filter(id=fid).first().price
        try:
            PayOrderModel.objects.create(uid=user_id,order_num =order_num,bid=bid,fid=fid,amount=price)
        except Exception as e:
            print(e,"生成未支付用户订单保存")
            return Response({
                "code": 305,
                "msg": "用户添加订单失败"
            })

        return Response({
            "code":200,
            "msg":"用户添加订单成功"
        })
    @check_login
    def delete(self,request):
        user_id = request.id
        id = request.data.get("id")
        try:
            ss=PayOrderModel.objects.filter(uid=user_id).filter(id=id).first()
            ss.delete()
        except Exception as e:
            print(e, "删除用户订单报错")
            return Response({
                "code": 305,
                "msg": "用户删除订单失败"
            })

        return Response({
            "code": 200,
            "msg": "用户删除订单成功"
        })
import time
from myapp.models import PayVipModel
class VipCreateView(APIView):
    @check_login
    def post(self,request):
        user_id = request.id
        u = UserModel.objects.get(id = user_id)
        vip_order_num = "T" + datetime.strftime(datetime.now(), "%Y%m%d%H%M%S") + str(
            random.randint(100000, 999999)) + str(
            random.randint(100000, 999999))

        vid = request.data.get('id')
        amount = request.data.get('price')
        times = request.data.get('time')

        PayVipModel.objects.create(
            vip_order_num=vip_order_num,
            uid_id= user_id,
            vid_id=vid,
            amount=amount,
        )
        user_info = UserModel.objects.get(id=user_id)
        if user_info.vip_start_time== '':
            user_info.vip_start_time = int(time.time())
        if user_info.vip_end_time == '':
            user_info.vip_end_time = int(time.time()) + int(times)
        else:
            user_info.vip_end_time += int(times)
        user_info.status = 1
        user_info.save()
        with open("./keys/alipay_public_key.txt", "r", encoding="utf-8") as f:
            alipay_public_key = f.read()
            f.close()

        with open("./keys/private_key.txt", "r", encoding="utf-8") as f:
            private_key = f.read()
            f.close()
        from alipay import AliPay
        # 2. 实例化阿里的SDK
        alipay = AliPay(
            appid="2021000121639230",  # APPID 从 open.alipay.com 获取
            app_private_key_string=private_key,  # 使用密钥生成工具生成的
            alipay_public_key_string=alipay_public_key,  # 用我们自己生成的公钥，与支付宝官方换来的支付宝的公钥
            debug=True,  # 调试模式打开
        )
        urls = alipay.api_alipay_trade_page_pay(  # 此方法是用来网页支付的
            subject="支付订单 - %s" % u.username,  # 订单标题
            out_trade_no=vip_order_num,  # 我们自己平台的订单号
            total_amount=amount,  # 支付金额，字符串形式。精确到两位小数
            return_url="http://127.0.0.1:8000/api.wm/v1/user/pay_notify",  # 同步回调地址
            notify_url="https://www.baidu.com/",  # 异步回调地址,没有上线做不了，等上线后再说
        )
        url = "https://openapi.alipaydev.com/gateway.do?" + urls
        return Response({
            "code":200,
            "url": url,
        })


class Goods_PayView(APIView):
    @check_login
    def post(self,request):
        user_id = request.id
        data = request.data.get('vip')
        u = UserModel.objects.get(id=user_id)
        # 获取一下商品信息
        for i in data:
            OrderModel.objects.create(
                uid_id=i.uid,
                fid_id=i.fid,
                bid_id=i.bid,
                num = i.num
            )
        user_id = request.id
        money = request.data.get('money')
        # 生成订单号
        order_num = "T" + datetime.strftime(datetime.now(), "%Y%m%d%H%M%S") + str(
            random.randint(100000, 999999)) + str(
            random.randint(100000, 999999))


        user_info = UserModel.objects.filter(id =user_id).first()
        if not user_info:
            return Response({
                "code":303,
                "msg":"用户未登录"
            })
        PayOrderModel.objects.create(
            order_num=order_num,
            amount=money,
            status="0"
        )

        with open("./keys/alipay_public_key.txt", "r", encoding="utf-8") as f:
            alipay_public_key = f.read()
            f.close()

        with open("./keys/private_key.txt", "r", encoding="utf-8") as f:
            private_key = f.read()
            f.close()
        from alipay import AliPay
        # 2. 实例化阿里的SDK
        alipay = AliPay(
            appid="2021000121639230",  # APPID 从 open.alipay.com 获取
            app_private_key_string=private_key,  # 使用密钥生成工具生成的
            alipay_public_key_string=alipay_public_key,  # 用我们自己生成的公钥，与支付宝官方换来的支付宝的公钥
            debug=True,  # 调试模式打开
        )
        urls = alipay.api_alipay_trade_page_pay(  # 此方法是用来网页支付的
            subject="支付订单 - %s" % u.username,  # 订单标题
            out_trade_no=order_num,  # 我们自己平台的订单号
            total_amount=money,  # 支付金额，字符串形式。精确到两位小数
            return_url="http://127.0.0.1:8000/api.wm/v1/user/pay_notify",  # 同步回调地址
            notify_url="https://www.baidu.com/",  # 异步回调地址,没有上线做不了，等上线后再说
        )
        url = "https://openapi.alipaydev.com/gateway.do?" + urls
        return Response({
            "code":200,
            "url": url,
        })


class PayNotifyView(APIView):
    def get(self,request):
        """接收同步地址回调"""
        args = request.query_params
        num = args.get('out_trade_no')
        print(type(num))

        # 因为是get请求，且地址啥的都是公开的。为了保证安全性，需要对回调数据进行校验
        # 把订单的状态改为已支
        order = PayOrderModel.objects.filter(order_num = str(num)).first()
        vip = PayVipModel.objects.filter(vip_order_num= str(num)).first()
        if order:
            print('xxxxxxx',order)
            if order.status == '0':
                order.status = '1'
                order.save()
        elif vip:
            if vip.status == '0':
                vip.status = '1'
                vip.save()
        else:
            return Response({
                'code':400,
                'msg':'订单状态不允许'
            })
        return redirect("http://localhost:8080/home")


class OrderRecordView(APIView):
    @check_login
    def get(self,request):
        user_id =request.id
        order_list = PayVipModel.objects.filter(uid_id=user_id).all()
        order_all = []
        lst = []
        for item in order_list:
            data = OrderModel.objects.filter(oid_id=item.id).all()
            for i in data:
                lst.append({
                    "bid":i.bid_id,
                    'fid':i.fid.name,
                    'food_img':i.fid.food_img,
                    'num':i.num,
                    'price':i.fid.price
                })
            order_all.append({
                "order_num": item.oid.order_num,
                "amount": item.oid.amount,
                "status": item.oid.status,
                'data':lst
            })

        return Response({
            "code":200,
            "msg":"获取支付记录成功",
            "data":order_all
        })

class VipAllView(APIView):
    @check_login
    def get(self,request):
        user_id = request.id
        data = PayVipModel.objects.filter(uid_id=user_id).all()
        lst = []
        for i in data:
            lst.append({
                'id':i.id,
                "vip_order_num":i.vip_order_num,
                "vid_text":i.vid.time_text,
                "amount":i.amount,
                "status":i.status,
                'name':i.vid.name
            })
        return Response({
            'code':200,
            'msg':'获取成功',
            'data':lst
        })


"""clmapp URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path
from myapp.views import *
urlpatterns = [
    path("send_code/",Sms_CodeView.as_view()),
    path("login/",LoginView.as_view()),
    path("out_login/",LogoutView.as_view()),
    path("show_user/",Show_userInfo.as_view()),
    path("qntoken/", QNYtoken.as_view()),
    path("addresss/", ShowUser_address.as_view()),
    path("coupons/", Showuser_Coupon.as_view()),
    path("vip_list/", VipListView.as_view()),
    path("order/", Add_OrderView.as_view()),
    path("food/", Goods_PayView.as_view()),
    path("pay_notify/", PayNotifyView.as_view()),
    path("order_record/",OrderRecordView.as_view()),
    path("cates/",CateView.as_view()),
    path('addvip/',VipCreateView.as_view()),
    path('allvip/',VipAllView.as_view())

]



# Generated by Django 2.2.12 on 2022-12-04 13:08

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BussessModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(default='', max_length=56, verbose_name='商家名称')),
                ('img', models.CharField(default='', max_length=256, verbose_name='商家封面')),
                ('start_time', models.CharField(default='', max_length=56, verbose_name='营业时间')),
                ('address', models.CharField(default='', max_length=124, verbose_name='商家地址')),
                ('phone', models.CharField(max_length=16, verbose_name='商家电话')),
                ('fen', models.CharField(default='', max_length=56, verbose_name='商家评分')),
                ('state', models.CharField(default=0, max_length=16, verbose_name='营业状态 0 下线 1上线')),
            ],
            options={
                'db_table': 'bussess_model',
            },
        ),
        migrations.CreateModel(
            name='CategoryModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=56, verbose_name='分类名')),
                ('num', models.CharField(default=0, max_length=16, verbose_name='排序，数字越小越靠前')),
            ],
            options={
                'db_table': 'category_model',
            },
        ),
        migrations.CreateModel(
            name='FoodModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=56, verbose_name='菜品名')),
                ('food_img', models.CharField(max_length=256, verbose_name='菜品图')),
                ('price', models.CharField(max_length=16, verbose_name='商品价格')),
                ('verbose_name', models.CharField(max_length=124, verbose_name='菜品评价')),
                ('pay_count', models.CharField(max_length=16, verbose_name='菜品销量')),
                ('cun_count', models.CharField(max_length=16, verbose_name='菜品库存量')),
                ('b_id', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.BussessModel', verbose_name='所属商家')),
            ],
            options={
                'db_table': 'food_model',
            },
        ),
        migrations.CreateModel(
            name='OrderLobbyModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(default=0, max_length=16, verbose_name='0 待抢单，1 已抢单')),
            ],
            options={
                'db_table': 'order_lobby_model',
            },
        ),
        migrations.CreateModel(
            name='RiderModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('r_name', models.CharField(max_length=32, unique=True, verbose_name='用户名')),
                ('mobile', models.CharField(max_length=16, unique=True, verbose_name='手机号')),
                ('img', models.CharField(max_length=256, verbose_name='头像')),
                ('login_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='登录时间')),
                ('reg_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='注册时间')),
                ('intro', models.CharField(default='这个人懒，什么也没写', max_length=256, verbose_name='用户简介')),
                ('status', models.CharField(default=0, max_length=32, verbose_name='是否上线 0 下线 1上线')),
            ],
            options={
                'db_table': 'rider_model',
            },
        ),
        migrations.CreateModel(
            name='UserModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('username', models.CharField(max_length=32, unique=True, verbose_name='用户名')),
                ('mobile', models.CharField(max_length=16, unique=True, verbose_name='手机号')),
                ('img', models.CharField(max_length=256, verbose_name='头像')),
                ('login_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='登录时间')),
                ('reg_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='注册时间')),
                ('intro', models.CharField(default='这个人懒，什么也没写', max_length=256, verbose_name='用户简介')),
                ('vip_start_time', models.CharField(default='', max_length=56, verbose_name='vip开始时间')),
                ('vip_end_time', models.CharField(default='', max_length=56, verbose_name='vip结束时间')),
                ('status', models.CharField(default=0, max_length=32, verbose_name='是否冻结 0 不冻结 1 冻结')),
            ],
            options={
                'db_table': 'user_model',
            },
        ),
        migrations.CreateModel(
            name='VipListModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=56, verbose_name='VIP名字')),
                ('price', models.CharField(default=0, max_length=16, verbose_name='价格')),
                ('time_text', models.CharField(default='', max_length=124, verbose_name='有效期')),
                ('time', models.CharField(default=0, max_length=56, verbose_name='有效期（s）')),
            ],
            options={
                'db_table': 'vip_list_model',
            },
        ),
        migrations.CreateModel(
            name='RiderOrderModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(default=0, max_length=16, verbose_name='0 接单 1 完成订单 2 转让订单')),
                ('order_id', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.OrderLobbyModel', verbose_name='订单ID')),
            ],
            options={
                'db_table': 'rider_order_model',
            },
        ),
        migrations.CreateModel(
            name='PayVipModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('vip_order_num', models.CharField(default='', max_length=555, verbose_name='订单号')),
                ('amount', models.CharField(max_length=16, verbose_name='支付金额')),
                ('status', models.CharField(default=0, max_length=16, verbose_name='订单状态  0 待支付  1已支付  2 已取消')),
                ('uid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.UserModel', verbose_name='用户id')),
                ('vid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.VipListModel', verbose_name='vip类型id')),
            ],
            options={
                'db_table': 'pay_vip_model',
            },
        ),
        migrations.CreateModel(
            name='PayOrderModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order_num', models.CharField(default='', max_length=56, verbose_name='订单号')),
                ('amount', models.CharField(default=0, max_length=16, verbose_name='支付金额')),
                ('status', models.CharField(default=0, max_length=16, verbose_name='订单状态  0 待支付  1已支付  2 已取消')),
                ('uid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.UserModel', verbose_name='用户id')),
            ],
            options={
                'db_table': 'pay_order_model',
            },
        ),
        migrations.CreateModel(
            name='OrderModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('num', models.IntegerField(verbose_name='数量')),
                ('bid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.BussessModel', verbose_name='订单商家id')),
                ('fid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.FoodModel', verbose_name='菜品id')),
                ('oid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.PayOrderModel', verbose_name='订单ID')),
            ],
            options={
                'db_table': 'order_model',
            },
        ),
        migrations.AddField(
            model_name='orderlobbymodel',
            name='o_id',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.PayOrderModel', verbose_name='订单ID'),
        ),
        migrations.CreateModel(
            name='CouponModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=56, verbose_name='优惠卷名')),
                ('price', models.CharField(max_length=16, verbose_name='优惠卷金额')),
                ('type', models.CharField(max_length=56, verbose_name='优惠卷类型')),
                ('start_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='开始时间')),
                ('end_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='结束时间')),
                ('time', models.CharField(default=0, max_length=56, verbose_name='有效期（s）')),
                ('uid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.UserModel', verbose_name='优惠卷用户')),
            ],
            options={
                'db_table': 'coupon_model',
            },
        ),
        migrations.CreateModel(
            name='CommentModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('context', models.CharField(default='', max_length=256, verbose_name='评论内容')),
                ('parent_id', models.IntegerField(default=0, verbose_name='回复的评论ID')),
                ('root_id', models.IntegerField(default=0, verbose_name='回复的评论根ID')),
                ('buss_id', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.BussessModel', verbose_name='商家id')),
                ('user_id', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.UserModel', verbose_name='用户id')),
            ],
            options={
                'db_table': 'comment_model',
            },
        ),
        migrations.AddField(
            model_name='bussessmodel',
            name='cid',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.CategoryModel', verbose_name='商家所属分类'),
        ),
        migrations.CreateModel(
            name='AddressModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=24, verbose_name='收货人姓名')),
                ('phone', models.CharField(max_length=16, verbose_name='收货人电话')),
                ('address', models.CharField(max_length=256, verbose_name='收货地址')),
                ('is_mo', models.CharField(default=0, max_length=4, verbose_name='1为默认地址，0为不默认')),
                ('uid', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='myapp.UserModel', verbose_name='收货用户')),
            ],
            options={
                'db_table': 'address_model',
            },
        ),
    ]



from django.shortcuts import render,HttpResponse
from rest_framework.views import APIView
from rest_framework.response import Response
from utils.sms_code import send_message
import string
import random
from captcha.image import ImageCaptcha
import redis
import jwt
from myapp.models import *
import time
from django.conf import settings
from utils.LoginTools import check_login
# Create your views here.
# 商家视图


# 图片验证码的视图
class ImageCodeAPIView(APIView):
    def get(self, request, uuid):
        # 生成一个4位数随机码
        # string.ascii_letters：a-zA-Z所有字母
        # string.digits：数字0-9
        # random.sample：随机采样(返回列表类型)
        code = "".join(random.sample(string.ascii_letters + string.digits, 4))
        # 实例化一个图片验证码对象
        # 用captcha.image下的 ImageCaptcha 生成字符验证码图片
        img = ImageCaptcha()
        # 把这个验证码转换成图片形式的
        image_code = img.generate(code)  # 字节io对象
        # 验证码存入redis
        redis_conn = redis.Redis(host="localhost", port=6379)
        redis_conn.set(uuid, code, ex=5 * 60)

        # 返回响应
        return HttpResponse(image_code, content_type="image/png")


# 获取验证码
class SmsView(APIView):
    def get(self,request,mobile):
        uuid = request.query_params.get('uuid')
        code = request.query_params.get('code')
        if not all([uuid,code]):
            return Response({
                'code':400,
                'msg':'获取数据为空'
            })
        print('>>>>>>>>>>',uuid,code)
        # 取出redis中uuid的值
        redis_conn = redis.Redis(host="localhost", port=6379)
        code_r = redis_conn.get(uuid)
        if not code_r:
            return Response({
                'code':400,
                'msg':'校验码已过期'
            })
        # 验证码还未过期，解码与前端对比
        if code_r.decode().lower() != code.lower():
            return Response({
                "code": 400,
                "msg": "校验码错误"
            })

        send_message(mobile)
        return Response({
            'code':200,
            'msg':'发送成功'
        })


# 手机验证码登入或注册
class UserView(APIView):
    def post(self,request):
        mobile = request.data.get('mobile')
        sms = request.data.get('sms')
        if not all([mobile,sms]):
            return Response({
                'code':400,
                'msg':'获取数据为空'
            })

        # 取出redis中uuid的值
        redis_conn = redis.Redis(host="localhost", port=6379)
        key = 'sms_%s' % mobile
        code_r = redis_conn.get(key)
        if not code_r:
            return Response({
                'code': 400,
                'msg': '验证码已过期'
            })
        # 验证码还未过期，解码与前端对比
        if code_r.decode().lower() != sms.lower():
            return Response({
                "code": 400,
                "msg": "验证码错误"
            })

        # 判断此手机号是否注册
        user = BussessModel.objects.filter(mobile=mobile)
        if not user:
            # 没有注册，进行注册
            BussessModel.objects.create(
                mobile=mobile,
            )
        try:
            user = BussessModel.objects.get(mobile=mobile)
        except Exception as e:
            return Response({
                'code':400,
                'msg':'没有此信息'
            })

        token = jwt.encode({
            'uid':user.id,
            'username':user.b_name,
            'exp':time.time() + 720000
        },key=settings.SECRET_KEY,algorithm='HS256')

        return Response({
            'code':200,
            'msg':'登入成功',
            'token':token
        })


# 对商品类别的增删改查  在平台操作
class ClassifyView(APIView):
    def get(self,request):
        # 获取所有分类
        food = FoodModel.objects.filter(delete=False)
        food_list = []
        for i in food:
            food_list.append({
                'cid':i.id,
                'name':i.name,
                'food_img':i.food_img,
            })

        return Response({
            'code':200,
            'msg':'获取分类商品成功',
            'data':food_list,
        })

    def post(self,request):
        name = request.data.get('name')
        img = request.data.get('img')
        pay_count = request.data.get('pay_count')
        cun_count = request.data.get('cun_count')
        price = request.data.get('price')
        verbose_name = request.data.get('verbose_name')
        if not all([img, name,pay_count,cun_count,price,verbose_name]):
            return Response({
                'code':400,
                'msg':'获取的数据为空'
            })

        # 唯一性判断
        food = FoodModel.objects.filter(name=name)
        if food:
            return Response({
                'code':400,
                'msg':'已有此分类'
            })

        FoodModel.objects.create(
            name=name,
            img=img,
            price=price,
            verbose_name=verbose_name,
            pay_count=pay_count,
            cun_count = cun_count
        )

        return Response({
            'code':200,
            'msg':"添加成功"
        })

# 商品的编辑获取删除
class ClassifyInfoView(APIView):
    def get(self,request,id):
        try:
            food = FoodModel.objects.get(id=id)
            return Response({
                'code':200,
                'msg':'获取成功',
                'data':{
                    "id":food.id,
                    'name':food.c_name,
                    'img':food.c_img,
                    "pay_count":food.pay_count,
                    'cun_count':food.cun_count,
                    "price":food.price,
                    'verbose_name':food.verbose_name
                }
            })
        except Exception as e:
            print(">?>>>>>",e)
            return Response({
                'code':400,
                'msg':'获取商品分类失败'
            })

    def put(self,request,id):
        # 获取前端数据
        name = request.data.get('name')
        img = request.data.get('img')
        pay_count = request.data.get('pay_count')
        cun_count = request.data.get('cun_count')
        price = request.data.get('price')
        verbose_name = request.data.get('verbose_name')

        if not all([img, name,pay_count,cun_count,price,verbose_name]):
            return Response({
                'code': 400,
                'msg': '获取的数据为空'
            })

        try:
            food = FoodModel.objects.get(id=id)
            food.name = name
            food.img = img
            food.pay_count = pay_count
            food.cun_count = cun_count
            food.price = price
            food.save()

            return Response({
                'code':200,
                'msg':'商品分类修改成功'
            })

        except Exception as e:
            print(">?>>>>>",e)
            return Response({
                'code':400,
                'msg':'获取商品分类失败'
            })

    def delete(self,request,id):
        try:
            food = FoodModel.objects.filter(id=id).delete()

            return Response({
                'code':200,
                'msg':'删除成功'
            })

        except Exception as e:
            print(">>>>>>>",e)
            return Response({
                'code':400,
                'msg':'没有此分类'
            })


class StatusView(APIView):
    @check_login
    def put(self,requst):
        id = requst.uid
        state = requst.data.get('state')
        data = BussessModel.objects.filter(id=id).update(state=state)
        return Response({
            'code':200,
            'msg':'修改成功'
        })









# Create your models here.
from django.db import models
from datetime import datetime

# Create your models here.
# 用户表
class UserModel(models.Model):
    username=models.CharField(max_length=32,verbose_name="用户名",unique=True)
    mobile = models.CharField(max_length=16,verbose_name="手机号",unique=True)
    img = models.CharField(max_length=256, verbose_name="头像")
    login_time = models.DateTimeField(default=datetime.now,verbose_name="登录时间")
    reg_time= models.DateTimeField(default=datetime.now,verbose_name="注册时间")
    intro = models.CharField(max_length=256,default="这个人懒，什么也没写",verbose_name="用户简介")
    vip_start_time = models.CharField(max_length=56,default='', verbose_name="vip开始时间")
    vip_end_time = models.CharField(max_length=56,default='', verbose_name="vip结束时间")
    status=models.CharField(max_length=32,default=0,verbose_name="是否冻结 0 不冻结 1 冻结")
    def __str__(self):
        return self.username
    class Meta:
        db_table = 'user_model'

# vip类型表
class VipListModel(models.Model):
    name=models.CharField(max_length=56,verbose_name="VIP名字")
    price=models.CharField(max_length=16,default=0,verbose_name="价格")
    time_text=models.CharField(max_length=124,default="",verbose_name="有效期")
    time=models.CharField(max_length=56,default=0,verbose_name="有效期（s）")
    def __str__(self):
        return self.name
    class Meta:
        db_table = 'vip_list_model'
# 购买vip表
class PayVipModel(models.Model):
    vip_order_num = models.CharField(max_length=555,default="", verbose_name="订单号")
    uid = models.ForeignKey(to=UserModel,on_delete=models.CASCADE,verbose_name="用户id")
    vid = models.ForeignKey(to=VipListModel,on_delete=models.CASCADE,verbose_name="vip类型id")
    amount = models.CharField(max_length=16,verbose_name="支付金额")
    status = models.CharField(max_length=16,default=0, verbose_name="订单状态  0 待支付  1已支付  2 已取消")
    def __str__(self):
        return self.vip_order_num
    class Meta:
        db_table = 'pay_vip_model'



# 商家分类表
class CategoryModel(models.Model):
    name = models.CharField(max_length=56,default="",verbose_name="分类名")
    num = models.CharField(max_length=16, default=0,verbose_name="排序，数字越小越靠前")
    def __str__(self):
        return self.name
    class Meta:
        db_table = 'category_model'

# 商家表
class BussessModel(models.Model):
    title = models.CharField(max_length=56,default="",verbose_name="商家名称")
    cid = models.ForeignKey(to=CategoryModel,on_delete=models.CASCADE,verbose_name="商家所属分类")
    img = models.CharField(max_length=256, default="",verbose_name="商家封面")
    start_time = models.CharField(max_length=56, default="", verbose_name="营业时间")
    address = models.CharField(max_length=124, default="",verbose_name="商家地址")
    phone= models.CharField(max_length=16,verbose_name="商家电话")
    fen=models.CharField(max_length=56, default="",verbose_name="商家评分")
    state = models.CharField(max_length=16, default=0, verbose_name="营业状态 0 下线 1上线")
    def __str__(self):
        return self.title
    class Meta:
        db_table = 'bussess_model'

# 商家菜品表
class FoodModel(models.Model):
    b_id = models.ForeignKey(to=BussessModel, on_delete=models.CASCADE, verbose_name="所属商家")
    name = models.CharField(max_length=56,default="",verbose_name="菜品名")
    food_img = models.CharField( max_length=256, verbose_name="菜品图")
    price = models.CharField(max_length=16,verbose_name="商品价格")
    verbose_name=models.CharField(max_length=124,verbose_name="菜品评价")
    pay_count=models.CharField(max_length=16,verbose_name="菜品销量")
    cun_count = models.CharField(max_length=16,verbose_name="菜品库存量")
    def __str__(self):
        return self.name
    class Meta:
        db_table = 'food_model'

# 用户收货地址表
class AddressModel(models.Model):
    uid=models.ForeignKey(to=UserModel,on_delete=models.CASCADE,verbose_name="收货用户")
    name=models.CharField(max_length=24,verbose_name="收货人姓名")
    phone=models.CharField(max_length=16,verbose_name="收货人电话")
    address=models.CharField(max_length=256,verbose_name="收货地址")
    is_mo=models.CharField(max_length=4,default=0,verbose_name="1为默认地址，0为不默认")
    def __str__(self):
        return self.name
    class Meta:
        db_table = 'address_model'

# 用户优惠卷表
class CouponModel(models.Model):
    uid=models.ForeignKey(to=UserModel,on_delete=models.CASCADE,verbose_name="优惠卷用户")
    name=models.CharField(max_length=56,verbose_name="优惠卷名")
    price=models.CharField(max_length=16,verbose_name="优惠卷金额")
    type=models.CharField(max_length=56,verbose_name="优惠卷类型")
    start_time = models.DateTimeField(default=datetime.now, verbose_name="开始时间")
    end_time = models.DateTimeField(default=datetime.now, verbose_name="结束时间")
    time = models.CharField(max_length=56, default=0, verbose_name="有效期（s）")
    def __str__(self):
        return self.name
    class Meta:
        db_table = 'coupon_model'

# 用户订单表
class PayOrderModel(models.Model):
    uid = models.ForeignKey(to=UserModel, on_delete=models.CASCADE, verbose_name="用户id")
    order_num = models.CharField(max_length=56, default="",verbose_name='订单号')
    amount = models.CharField(max_length=16, default=0, verbose_name="支付金额")
    status = models.CharField(max_length=16, default=0,verbose_name="订单状态  0 待支付  1已支付  2 已取消")
    def __str__(self):
        return self.order_num
    class Meta:
        db_table = 'pay_order_model'

class OrderModel(models.Model):
    bid = models.ForeignKey(to=BussessModel, on_delete=models.CASCADE, verbose_name="订单商家id")
    fid = models.ForeignKey(to=FoodModel, on_delete=models.CASCADE, verbose_name="菜品id")
    oid = models.ForeignKey(to=PayOrderModel,on_delete=models.CASCADE,verbose_name='订单ID')
    num = models.IntegerField(verbose_name='数量')
    class Meta:
        db_table = 'order_model'

# 商家评论表
class CommentModel(models.Model):
    user_id = models.ForeignKey(to=UserModel,on_delete=models.CASCADE,verbose_name="用户id")
    buss_id = models.ForeignKey(to=BussessModel,on_delete=models.CASCADE,verbose_name="商家id")
    context = models.CharField(max_length=256, default="",verbose_name="评论内容")
    parent_id = models.IntegerField(default=0,verbose_name="回复的评论ID")
    root_id = models.IntegerField(default=0,verbose_name="回复的评论根ID")
    def __str__(self):
        return self.context
    class Meta:
        db_table = 'comment_model'

#骑手表
class RiderModel(models.Model):
    r_name = models.CharField(max_length=32, verbose_name="用户名", unique=True)
    mobile = models.CharField(max_length=16, verbose_name="手机号", unique=True)
    img = models.CharField(max_length=256, verbose_name="头像")
    login_time = models.DateTimeField(default=datetime.now, verbose_name="登录时间")
    reg_time = models.DateTimeField(default=datetime.now, verbose_name="注册时间")
    intro = models.CharField(max_length=256, default="这个人懒，什么也没写", verbose_name="用户简介")
    status = models.CharField(max_length=32,default=0, verbose_name="是否上线 0 下线 1上线")
    def __str__(self):
        return self.r_name
    class Meta:
        db_table = 'rider_model'

#抢单大厅
class OrderLobbyModel(models.Model):
    o_id = models.ForeignKey(to=PayOrderModel,on_delete=models.CASCADE,verbose_name='订单ID')
    status = models.CharField(max_length=16,default=0,verbose_name='0 待抢单，1 已抢单')
    def __str__(self):
        return self.status
    class Meta:
        db_table = 'order_lobby_model'
#骑手订单表
class RiderOrderModel(models.Model):
    order_id = models.ForeignKey(to=OrderLobbyModel,on_delete=models.CASCADE,verbose_name='订单ID')
    status = models.CharField(max_length=16,default=0,verbose_name='0 接单 1 完成订单 2 转让订单')
    def __str__(self):
        return self.status
    class Meta:
        db_table = 'rider_order_model'

























"""takes URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path
from bussess.views import *
urlpatterns = [
    # 获取手机验证码接口
    path('sms/<str:mobile>/',SmsView.as_view()),
    # 图片验证码的接口
    path("image_code/<str:uuid>/", ImageCodeAPIView.as_view()),
    # 手机号验证码登入
    path('login/',UserView.as_view()),
    # 商品的获取和添加
    path('classify/',ClassifyView.as_view()),
    # 商品的编辑和删除
    path('classify/<int:id>/',ClassifyInfoView.as_view()),


]




import setuptools
import os

# 这是一个和根目录相关的安装文件的列表，列表中setup.py更具体)

files = ["waimai/*"]

setuptools.setup(
      name='yindd',
      version='1.0.0',
      keywords='jwt_f',
      description='jwt',
      long_description=open(
            os.path.join(
                  os.path.dirname(__file__),
                  'README.md'
            )
      ).read(),
      author='Dada.cod',
      author_email='1078515202@qq.com',
      packages=setuptools.find_packages(),
      license='MIT'
)
